aboutsummaryrefslogtreecommitdiff
path: root/Perl/Zinc/Trace.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Perl/Zinc/Trace.pm')
-rw-r--r--Perl/Zinc/Trace.pm12
1 files changed, 7 insertions, 5 deletions
diff --git a/Perl/Zinc/Trace.pm b/Perl/Zinc/Trace.pm
index ec284d8..fcd595f 100644
--- a/Perl/Zinc/Trace.pm
+++ b/Perl/Zinc/Trace.pm
@@ -17,12 +17,14 @@
# This may be very usefull when your application segfaults and
# when you have no idea where this happens in your code.
#
# To trap Tk::Zinc errors, use rather the ZincTraceErrors package.
#
# for using this file do some thing like :
-# perl -MZincTrace myappli.pl
+# perl -MTk::Zinc::Trace myappli.pl
-package ZincTrace;
+package Tk::Zinc::Trace;
use vars qw( $VERSION );
($VERSION) = sprintf("%d.%02d", q$Revision$ =~ /(\d+)\.(\d+)/);
@@ -34,11 +36,11 @@ use Tk::Zinc::TraceUtils;
my $WidgetMethodfunction;
BEGIN {
if ($ZincTraceErrors::on == 1) {
- print STDERR "ZincTrace: incompatible package ZincTraceErrors is already ".
+ print STDERR "Tk::Zinc::Trace: incompatible package Tk::Zinc::TraceErrors is already ".
"loaded (exit 1)\n";
exit 1;
}
- print "ZincTrace is ON\n";
+ print "Tk::Zinc::Trace is ON\n";
$ZincTrace::on = 1;
select STDOUT; $|=1; ## for flushing the trace output
# save current Tk::Zinc::InitObject function; it will be invoked in
@@ -17,12 +17,14 @@
# when you have no idea where this happens in your code.
#
-# To trap Tk::Zinc errors, use rather the ZincTraceErrors package.
+# $Id$
+#
+# To trap Tk::Zinc errors, use rather the Tk::Zinc::TraceErrors package.
#
# for using this file do some thing like :